@@ -242,9 +242,6 @@ def fc_ga(processing_times, due_dates, penalties):
     for i in range(1, num_jobs+1, 5):
         population_size += 30
         generations += 30*i
-#     print(population_size)
-#     print(generations)
-#     print('-------')
 
     def calculate_penalty(schedule):
         completions = [processing_times[schedule[0]]]
@@ -260,7 +257,8 @@ def fc_ga(processing_times, due_dates, penalties):
 
     # Create initial population
     population = [[i for i in range(len(processing_times))] for _ in range(population_size)]
-    rd.shuffle(population)
+    for sublist in population:
+        rd.shuffle(sublist)
 
     # Loop generations
     for _ in range(generations):
